# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/grpcinferenceservice/v1/grpcinferenceservice.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protoc_gen_swagger.options import annotations_pb2 as protoc__gen__swagger_dot_options_dot_annotations__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYgithub.com/metaprov/modelaapi/services/grpcinferenceservice/v1/grpcinferenceservice.proto\x12>github.com.metaprov.modelaapi.services.grpcinferenceservice.v1\x1a,protoc-gen-swagger/options/annotations.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x13\n\x11ServerLiveRequest\"\"\n\x12ServerLiveResponse\x12\x0c\n\x04live\x18\x01 \x01(\x08\"\x14\n\x12ServerReadyRequest\"$\n\x13ServerReadyResponse\x12\r\n\x05ready\x18\x01 \x01(\x08\"2\n\x11ModelReadyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"#\n\x12ModelReadyResponse\x12\r\n\x05ready\x18\x01 \x01(\x08\"\x17\n\x15ServerMetadataRequest\"K\n\x16ServerMetadataResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x12\n\nextensions\x18\x03 \x03(\t\"5\n\x14ModelMetadataRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xf7\x02\n\x15ModelMetadataResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08versions\x18\x02 \x03(\t\x12\x10\n\x08platform\x18\x03 \x01(\t\x12t\n\x06inputs\x18\x04 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelMetadataResponse.TensorMetadata\x12u\n\x07outputs\x18\x05 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelMetadataResponse.TensorMetadata\x1a?\n\x0eTensorMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tatype\x18\x02 \x01(\t\x12\r\n\x05shape\x18\x03 \x03(\x03\"\xd0\n\n\x11ModelInferRequest\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12u\n\nparameters\x18\x04 \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest.ParametersEntry\x12r\n\x06inputs\x18\x05 \x03(\x0b\x32\x62.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest.InferInputTensor\x12}\n\x07outputs\x18\x06 \x03(\x0b\x32l.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest.InferRequestedOutputTensor\x12\x1a\n\x12raw_input_contents\x18\x07 \x03(\x0c\x1a\xb5\x03\n\x10InferInputTensor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tatype\x18\x02 \x01(\t\x12\r\n\x05shape\x18\x03 \x03(\x03\x12\x86\x01\n\nparameters\x18\x04 \x03(\x0b\x32r.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest.InferInputTensor.ParametersEntry\x12\x65\n\x08\x63ontents\x18\x05 \x01(\x0b\x32S.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.InferTensorContents\x1a\x81\x01\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12]\n\x05value\x18\x02 \x01(\x0b\x32N.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.InferParameter:\x02\x38\x01\x1a\xc1\x02\n\x1aInferRequestedOutputTensor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x90\x01\n\nparameters\x18\x02 \x03(\x0b\x32|.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest.InferRequestedOutputTensor.ParametersEntry\x1a\x81\x01\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12]\n\x05value\x18\x02 \x01(\x0b\x32N.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.InferParameter:\x02\x38\x01\x1a\x81\x01\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12]\n\x05value\x18\x02 \x01(\x0b\x32N.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.InferParameter:\x02\x38\x01\"\x96\x07\n\x12ModelInferResponse\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rmodel_version\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12v\n\nparameters\x18\x04 \x03(\x0b\x32\x62.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferResponse.ParametersEntry\x12u\n\x07outputs\x18\x05 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferResponse.InferOutputTensor\x12\x1b\n\x13raw_output_contents\x18\x06 \x03(\x0c\x1a\xb8\x03\n\x11InferOutputTensor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tatype\x18\x02 \x01(\t\x12\r\n\x05shape\x18\x03 \x03(\x03\x12\x88\x01\n\nparameters\x18\x04 \x03(\x0b\x32t.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferResponse.InferOutputTensor.ParametersEntry\x12\x65\n\x08\x63ontents\x18\x05 \x01(\x0b\x32S.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.InferTensorContents\x1a\x81\x01\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12]\n\x05value\x18\x02 \x01(\x0b\x32N.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.InferParameter:\x02\x38\x01\x1a\x81\x01\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12]\n\x05value\x18\x02 \x01(\x0b\x32N.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.InferParameter:\x02\x38\x01\"i\n\x0eInferParameter\x12\x14\n\nbool_param\x18\x01 \x01(\x08H\x00\x12\x15\n\x0bint64_param\x18\x02 \x01(\x03H\x00\x12\x16\n\x0cstring_param\x18\x03 \x01(\tH\x00\x42\x12\n\x10parameter_choice\"\xd0\x01\n\x13InferTensorContents\x12\x15\n\rbool_contents\x18\x01 \x03(\x08\x12\x14\n\x0cint_contents\x18\x02 \x03(\x05\x12\x16\n\x0eint64_contents\x18\x03 \x03(\x03\x12\x15\n\ruint_contents\x18\x04 \x03(\r\x12\x17\n\x0fuint64_contents\x18\x05 \x03(\x04\x12\x15\n\rfp32_contents\x18\x06 \x03(\x02\x12\x15\n\rfp64_contents\x18\x07 \x03(\x01\x12\x16\n\x0e\x62ytes_contents\x18\x08 \x03(\x0c\"\xf5\x01\n\rPredictorInfo\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04task\x18\x03 \x01(\t\x12Y\n\x06models\x18\x04 \x03(\x0b\x32I.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInfo\x12Z\n\x06schema\x18\x05 \x01(\x0b\x32J.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.SchemaInfo\"\xbb\x02\n\tModelInfo\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0f\n\x07product\x18\x04 \x01(\t\x12\x16\n\x0etrainingMetric\x18\x05 \x01(\t\x12\x15\n\rtrainingScore\x18\x06 \x01(\x02\x12\x0e\n\x06status\x18\x07 \x01(\t\x12\x0e\n\x06\x63\x61nary\x18\x08 \x01(\x08\x12\x0e\n\x06shadow\x18\t \x01(\x08\x12\x0f\n\x07traffic\x18\n \x01(\x02\x12\x0e\n\x06\x66ilter\x18\x0b \x01(\t\x12\x0c\n\x04rank\x18\x0c \x01(\x03\x12\x0f\n\x07logPath\x18\r \x01(\t\x12\x0b\n\x03p95\x18\x0e \x01(\x02\x12\x0b\n\x03p99\x18\x0f \x01(\x02\x12\x16\n\x0elastPrediction\x18\x10 \x01(\x03\x12\x1a\n\x12\x64\x61ilyPredictionAvg\x18\x11 \x01(\x05\"i\n\nSchemaInfo\x12[\n\x07\x63olumns\x18\x01 \x03(\x0b\x32J.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ColumnInfo\"|\n\nColumnInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x12\n\ndatasetMin\x18\x03 \x01(\x02\x12\x13\n\x0b\x64\x61tasetMean\x18\x04 \x01(\x02\x12\x15\n\rdatasetStdDev\x18\x05 \x01(\x02\x12\x12\n\ndatasetMax\x18\x06 \x01(\x02\"\x15\n\x13GetPredictorRequest\"s\n\x14GetPredictorResponse\x12[\n\x04item\x18\x01 \x01(\x0b\x32M.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.PredictorInfo\"\x1f\n\x0fGetModelRequest\x12\x0c\n\x04name\x18\x03 \x01(\t\"k\n\x10GetModelResponse\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInfo\"\x84\x01\n\x0ePredictRequest\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08validate\x18\x03 \x01(\x08\x12\x0f\n\x07\x65xplain\x18\x04 \x01(\x08\x12\x0e\n\x06\x66ormat\x18\x05 \x01(\t\x12\x0f\n\x07payload\x18\x06 \x01(\t\x12\x0f\n\x07labeled\x18\x07 \x01(\x08\x12\x0f\n\x07metrics\x18\x08 \x03(\t\"\x93\x02\n\x0fPredictResponse\x12\x64\n\x05items\x18\x01 \x03(\x0b\x32U.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.PredictResultLineItem\x12k\n\x06scores\x18\x02 \x03(\x0b\x32[.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.PredictResponse.ScoresEntry\x1a-\n\x0bScoresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\xd1\x02\n\x15PredictResultLineItem\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05score\x18\x02 \x01(\x02\x12\r\n\x05label\x18\x03 \x01(\t\x12g\n\rprobabilities\x18\x04 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ProbabilityValue\x12\x16\n\x0emissingColumns\x18\x05 \x03(\t\x12\x12\n\noutOfBound\x18\x06 \x03(\t\x12\x15\n\rbaseShapValue\x18\x07 \x01(\x02\x12]\n\nshapValues\x18\x08 \x03(\x0b\x32I.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ShapValue\"6\n\x10ProbabilityValue\x12\r\n\x05label\x18\x01 \x01(\t\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\"+\n\tShapValue\x12\x0f\n\x07\x66\x65\x61ture\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x32\xe7\r\n\x14GRPCInferenceService\x12\xb5\x01\n\nServerLive\x12Q.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerLiveRequest\x1aR.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerLiveResponse\"\x00\x12\xb8\x01\n\x0bServerReady\x12R.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerReadyRequest\x1aS.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerReadyResponse\"\x00\x12\xb5\x01\n\nModelReady\x12Q.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelReadyRequest\x1aR.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelReadyResponse\"\x00\x12\xc1\x01\n\x0eServerMetadata\x12U.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerMetadataRequest\x1aV.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerMetadataResponse\"\x00\x12\xbe\x01\n\rModelMetadata\x12T.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelMetadataRequest\x1aU.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelMetadataResponse\"\x00\x12\xb5\x01\n\nModelInfer\x12Q.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest\x1aR.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferResponse\"\x00\x12\xd0\x01\n\x0cGetPredictor\x12S.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.GetPredictorRequest\x1aT.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.GetPredictorResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v1/predictor\x12\xc8\x01\n\x08GetModel\x12O.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.GetModelRequest\x1aP.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.GetModelResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/models/{name}\x12\xc8\x01\n\x07Predict\x12N.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.PredictRequest\x1aO.github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.PredictResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/models/{name}:\x01*B\x9e\x03\n!io.modela.grpcinferenceservice.v1B\x14GrpcInferenceServiceZ>github.com/metaprov/modelaapi/services/grpcinferenceservice/v1\xaa\x02\x1dModela.Client.Autogen.Grpc.v1\x92\x41\x81\x02\x12\x61\n\x14GrpcInferenceService\"D\n\x0emodela authors\x12\x11https://modela.ai\x1a\x1fmodela-discuss@googlegroups.com2\x03\x31.0*\x02\x01\x02\x32\x10\x61pplication/json:\x10\x61pplication/jsonR;\n\x03\x34\x30\x34\x12\x34\n*Returned when the resource does not exist.\x12\x06\n\x04\x9a\x02\x01\x07r7\n\x17modela.ai documentation\x12\x1chttps://modela.ai/site/docs/b\x06proto3')



_SERVERLIVEREQUEST = DESCRIPTOR.message_types_by_name['ServerLiveRequest']
_SERVERLIVERESPONSE = DESCRIPTOR.message_types_by_name['ServerLiveResponse']
_SERVERREADYREQUEST = DESCRIPTOR.message_types_by_name['ServerReadyRequest']
_SERVERREADYRESPONSE = DESCRIPTOR.message_types_by_name['ServerReadyResponse']
_MODELREADYREQUEST = DESCRIPTOR.message_types_by_name['ModelReadyRequest']
_MODELREADYRESPONSE = DESCRIPTOR.message_types_by_name['ModelReadyResponse']
_SERVERMETADATAREQUEST = DESCRIPTOR.message_types_by_name['ServerMetadataRequest']
_SERVERMETADATARESPONSE = DESCRIPTOR.message_types_by_name['ServerMetadataResponse']
_MODELMETADATAREQUEST = DESCRIPTOR.message_types_by_name['ModelMetadataRequest']
_MODELMETADATARESPONSE = DESCRIPTOR.message_types_by_name['ModelMetadataResponse']
_MODELMETADATARESPONSE_TENSORMETADATA = _MODELMETADATARESPONSE.nested_types_by_name['TensorMetadata']
_MODELINFERREQUEST = DESCRIPTOR.message_types_by_name['ModelInferRequest']
_MODELINFERREQUEST_INFERINPUTTENSOR = _MODELINFERREQUEST.nested_types_by_name['InferInputTensor']
_MODELINFERREQUEST_INFERINPUTTENSOR_PARAMETERSENTRY = _MODELINFERREQUEST_INFERINPUTTENSOR.nested_types_by_name['ParametersEntry']
_MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR = _MODELINFERREQUEST.nested_types_by_name['InferRequestedOutputTensor']
_MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR_PARAMETERSENTRY = _MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR.nested_types_by_name['ParametersEntry']
_MODELINFERREQUEST_PARAMETERSENTRY = _MODELINFERREQUEST.nested_types_by_name['ParametersEntry']
_MODELINFERRESPONSE = DESCRIPTOR.message_types_by_name['ModelInferResponse']
_MODELINFERRESPONSE_INFEROUTPUTTENSOR = _MODELINFERRESPONSE.nested_types_by_name['InferOutputTensor']
_MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY = _MODELINFERRESPONSE_INFEROUTPUTTENSOR.nested_types_by_name['ParametersEntry']
_MODELINFERRESPONSE_PARAMETERSENTRY = _MODELINFERRESPONSE.nested_types_by_name['ParametersEntry']
_INFERPARAMETER = DESCRIPTOR.message_types_by_name['InferParameter']
_INFERTENSORCONTENTS = DESCRIPTOR.message_types_by_name['InferTensorContents']
_PREDICTORINFO = DESCRIPTOR.message_types_by_name['PredictorInfo']
_MODELINFO = DESCRIPTOR.message_types_by_name['ModelInfo']
_SCHEMAINFO = DESCRIPTOR.message_types_by_name['SchemaInfo']
_COLUMNINFO = DESCRIPTOR.message_types_by_name['ColumnInfo']
_GETPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['GetPredictorRequest']
_GETPREDICTORRESPONSE = DESCRIPTOR.message_types_by_name['GetPredictorResponse']
_GETMODELREQUEST = DESCRIPTOR.message_types_by_name['GetModelRequest']
_GETMODELRESPONSE = DESCRIPTOR.message_types_by_name['GetModelResponse']
_PREDICTREQUEST = DESCRIPTOR.message_types_by_name['PredictRequest']
_PREDICTRESPONSE = DESCRIPTOR.message_types_by_name['PredictResponse']
_PREDICTRESPONSE_SCORESENTRY = _PREDICTRESPONSE.nested_types_by_name['ScoresEntry']
_PREDICTRESULTLINEITEM = DESCRIPTOR.message_types_by_name['PredictResultLineItem']
_PROBABILITYVALUE = DESCRIPTOR.message_types_by_name['ProbabilityValue']
_SHAPVALUE = DESCRIPTOR.message_types_by_name['ShapValue']
ServerLiveRequest = _reflection.GeneratedProtocolMessageType('ServerLiveRequest', (_message.Message,), {
  'DESCRIPTOR' : _SERVERLIVEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerLiveRequest)
  })
_sym_db.RegisterMessage(ServerLiveRequest)

ServerLiveResponse = _reflection.GeneratedProtocolMessageType('ServerLiveResponse', (_message.Message,), {
  'DESCRIPTOR' : _SERVERLIVERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerLiveResponse)
  })
_sym_db.RegisterMessage(ServerLiveResponse)

ServerReadyRequest = _reflection.GeneratedProtocolMessageType('ServerReadyRequest', (_message.Message,), {
  'DESCRIPTOR' : _SERVERREADYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerReadyRequest)
  })
_sym_db.RegisterMessage(ServerReadyRequest)

ServerReadyResponse = _reflection.GeneratedProtocolMessageType('ServerReadyResponse', (_message.Message,), {
  'DESCRIPTOR' : _SERVERREADYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerReadyResponse)
  })
_sym_db.RegisterMessage(ServerReadyResponse)

ModelReadyRequest = _reflection.GeneratedProtocolMessageType('ModelReadyRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODELREADYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelReadyRequest)
  })
_sym_db.RegisterMessage(ModelReadyRequest)

ModelReadyResponse = _reflection.GeneratedProtocolMessageType('ModelReadyResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELREADYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelReadyResponse)
  })
_sym_db.RegisterMessage(ModelReadyResponse)

ServerMetadataRequest = _reflection.GeneratedProtocolMessageType('ServerMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _SERVERMETADATAREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerMetadataRequest)
  })
_sym_db.RegisterMessage(ServerMetadataRequest)

ServerMetadataResponse = _reflection.GeneratedProtocolMessageType('ServerMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _SERVERMETADATARESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ServerMetadataResponse)
  })
_sym_db.RegisterMessage(ServerMetadataResponse)

ModelMetadataRequest = _reflection.GeneratedProtocolMessageType('ModelMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODELMETADATAREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelMetadataRequest)
  })
_sym_db.RegisterMessage(ModelMetadataRequest)

ModelMetadataResponse = _reflection.GeneratedProtocolMessageType('ModelMetadataResponse', (_message.Message,), {

  'TensorMetadata' : _reflection.GeneratedProtocolMessageType('TensorMetadata', (_message.Message,), {
    'DESCRIPTOR' : _MODELMETADATARESPONSE_TENSORMETADATA,
    '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelMetadataResponse.TensorMetadata)
    })
  ,
  'DESCRIPTOR' : _MODELMETADATARESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelMetadataResponse)
  })
_sym_db.RegisterMessage(ModelMetadataResponse)
_sym_db.RegisterMessage(ModelMetadataResponse.TensorMetadata)

ModelInferRequest = _reflection.GeneratedProtocolMessageType('ModelInferRequest', (_message.Message,), {

  'InferInputTensor' : _reflection.GeneratedProtocolMessageType('InferInputTensor', (_message.Message,), {

    'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
      'DESCRIPTOR' : _MODELINFERREQUEST_INFERINPUTTENSOR_PARAMETERSENTRY,
      '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
      # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest.InferInputTensor.ParametersEntry)
      })
    ,
    'DESCRIPTOR' : _MODELINFERREQUEST_INFERINPUTTENSOR,
    '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest.InferInputTensor)
    })
  ,

  'InferRequestedOutputTensor' : _reflection.GeneratedProtocolMessageType('InferRequestedOutputTensor', (_message.Message,), {

    'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
      'DESCRIPTOR' : _MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR_PARAMETERSENTRY,
      '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
      # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest.InferRequestedOutputTensor.ParametersEntry)
      })
    ,
    'DESCRIPTOR' : _MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR,
    '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest.InferRequestedOutputTensor)
    })
  ,

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _MODELINFERREQUEST_PARAMETERSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _MODELINFERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferRequest)
  })
_sym_db.RegisterMessage(ModelInferRequest)
_sym_db.RegisterMessage(ModelInferRequest.InferInputTensor)
_sym_db.RegisterMessage(ModelInferRequest.InferInputTensor.ParametersEntry)
_sym_db.RegisterMessage(ModelInferRequest.InferRequestedOutputTensor)
_sym_db.RegisterMessage(ModelInferRequest.InferRequestedOutputTensor.ParametersEntry)
_sym_db.RegisterMessage(ModelInferRequest.ParametersEntry)

ModelInferResponse = _reflection.GeneratedProtocolMessageType('ModelInferResponse', (_message.Message,), {

  'InferOutputTensor' : _reflection.GeneratedProtocolMessageType('InferOutputTensor', (_message.Message,), {

    'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
      'DESCRIPTOR' : _MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY,
      '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
      # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferResponse.InferOutputTensor.ParametersEntry)
      })
    ,
    'DESCRIPTOR' : _MODELINFERRESPONSE_INFEROUTPUTTENSOR,
    '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferResponse.InferOutputTensor)
    })
  ,

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _MODELINFERRESPONSE_PARAMETERSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferResponse.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _MODELINFERRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInferResponse)
  })
_sym_db.RegisterMessage(ModelInferResponse)
_sym_db.RegisterMessage(ModelInferResponse.InferOutputTensor)
_sym_db.RegisterMessage(ModelInferResponse.InferOutputTensor.ParametersEntry)
_sym_db.RegisterMessage(ModelInferResponse.ParametersEntry)

InferParameter = _reflection.GeneratedProtocolMessageType('InferParameter', (_message.Message,), {
  'DESCRIPTOR' : _INFERPARAMETER,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.InferParameter)
  })
_sym_db.RegisterMessage(InferParameter)

InferTensorContents = _reflection.GeneratedProtocolMessageType('InferTensorContents', (_message.Message,), {
  'DESCRIPTOR' : _INFERTENSORCONTENTS,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.InferTensorContents)
  })
_sym_db.RegisterMessage(InferTensorContents)

PredictorInfo = _reflection.GeneratedProtocolMessageType('PredictorInfo', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTORINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.PredictorInfo)
  })
_sym_db.RegisterMessage(PredictorInfo)

ModelInfo = _reflection.GeneratedProtocolMessageType('ModelInfo', (_message.Message,), {
  'DESCRIPTOR' : _MODELINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ModelInfo)
  })
_sym_db.RegisterMessage(ModelInfo)

SchemaInfo = _reflection.GeneratedProtocolMessageType('SchemaInfo', (_message.Message,), {
  'DESCRIPTOR' : _SCHEMAINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.SchemaInfo)
  })
_sym_db.RegisterMessage(SchemaInfo)

ColumnInfo = _reflection.GeneratedProtocolMessageType('ColumnInfo', (_message.Message,), {
  'DESCRIPTOR' : _COLUMNINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ColumnInfo)
  })
_sym_db.RegisterMessage(ColumnInfo)

GetPredictorRequest = _reflection.GeneratedProtocolMessageType('GetPredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.GetPredictorRequest)
  })
_sym_db.RegisterMessage(GetPredictorRequest)

GetPredictorResponse = _reflection.GeneratedProtocolMessageType('GetPredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.GetPredictorResponse)
  })
_sym_db.RegisterMessage(GetPredictorResponse)

GetModelRequest = _reflection.GeneratedProtocolMessageType('GetModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.GetModelRequest)
  })
_sym_db.RegisterMessage(GetModelRequest)

GetModelResponse = _reflection.GeneratedProtocolMessageType('GetModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.GetModelResponse)
  })
_sym_db.RegisterMessage(GetModelResponse)

PredictRequest = _reflection.GeneratedProtocolMessageType('PredictRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.PredictRequest)
  })
_sym_db.RegisterMessage(PredictRequest)

PredictResponse = _reflection.GeneratedProtocolMessageType('PredictResponse', (_message.Message,), {

  'ScoresEntry' : _reflection.GeneratedProtocolMessageType('ScoresEntry', (_message.Message,), {
    'DESCRIPTOR' : _PREDICTRESPONSE_SCORESENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.PredictResponse.ScoresEntry)
    })
  ,
  'DESCRIPTOR' : _PREDICTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.PredictResponse)
  })
_sym_db.RegisterMessage(PredictResponse)
_sym_db.RegisterMessage(PredictResponse.ScoresEntry)

PredictResultLineItem = _reflection.GeneratedProtocolMessageType('PredictResultLineItem', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTRESULTLINEITEM,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.PredictResultLineItem)
  })
_sym_db.RegisterMessage(PredictResultLineItem)

ProbabilityValue = _reflection.GeneratedProtocolMessageType('ProbabilityValue', (_message.Message,), {
  'DESCRIPTOR' : _PROBABILITYVALUE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ProbabilityValue)
  })
_sym_db.RegisterMessage(ProbabilityValue)

ShapValue = _reflection.GeneratedProtocolMessageType('ShapValue', (_message.Message,), {
  'DESCRIPTOR' : _SHAPVALUE,
  '__module__' : 'github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.grpcinferenceservice_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.grpcinferenceservice.v1.ShapValue)
  })
_sym_db.RegisterMessage(ShapValue)

_GRPCINFERENCESERVICE = DESCRIPTOR.services_by_name['GRPCInferenceService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.modela.grpcinferenceservice.v1B\024GrpcInferenceServiceZ>github.com/metaprov/modelaapi/services/grpcinferenceservice/v1\252\002\035Modela.Client.Autogen.Grpc.v1\222A\201\002\022a\n\024GrpcInferenceService\"D\n\016modela authors\022\021https://modela.ai\032\037modela-discuss@googlegroups.com2\0031.0*\002\001\0022\020application/json:\020application/jsonR;\n\003404\0224\n*Returned when the resource does not exist.\022\006\n\004\232\002\001\007r7\n\027modela.ai documentation\022\034https://modela.ai/site/docs/'
  _MODELINFERREQUEST_INFERINPUTTENSOR_PARAMETERSENTRY._options = None
  _MODELINFERREQUEST_INFERINPUTTENSOR_PARAMETERSENTRY._serialized_options = b'8\001'
  _MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR_PARAMETERSENTRY._options = None
  _MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR_PARAMETERSENTRY._serialized_options = b'8\001'
  _MODELINFERREQUEST_PARAMETERSENTRY._options = None
  _MODELINFERREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY._options = None
  _MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY._serialized_options = b'8\001'
  _MODELINFERRESPONSE_PARAMETERSENTRY._options = None
  _MODELINFERRESPONSE_PARAMETERSENTRY._serialized_options = b'8\001'
  _PREDICTRESPONSE_SCORESENTRY._options = None
  _PREDICTRESPONSE_SCORESENTRY._serialized_options = b'8\001'
  _GRPCINFERENCESERVICE.methods_by_name['GetPredictor']._options = None
  _GRPCINFERENCESERVICE.methods_by_name['GetPredictor']._serialized_options = b'\202\323\344\223\002\017\022\r/v1/predictor'
  _GRPCINFERENCESERVICE.methods_by_name['GetModel']._options = None
  _GRPCINFERENCESERVICE.methods_by_name['GetModel']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/models/{name}'
  _GRPCINFERENCESERVICE.methods_by_name['Predict']._options = None
  _GRPCINFERENCESERVICE.methods_by_name['Predict']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/models/{name}:\001*'
  _SERVERLIVEREQUEST._serialized_start=263
  _SERVERLIVEREQUEST._serialized_end=282
  _SERVERLIVERESPONSE._serialized_start=284
  _SERVERLIVERESPONSE._serialized_end=318
  _SERVERREADYREQUEST._serialized_start=320
  _SERVERREADYREQUEST._serialized_end=340
  _SERVERREADYRESPONSE._serialized_start=342
  _SERVERREADYRESPONSE._serialized_end=378
  _MODELREADYREQUEST._serialized_start=380
  _MODELREADYREQUEST._serialized_end=430
  _MODELREADYRESPONSE._serialized_start=432
  _MODELREADYRESPONSE._serialized_end=467
  _SERVERMETADATAREQUEST._serialized_start=469
  _SERVERMETADATAREQUEST._serialized_end=492
  _SERVERMETADATARESPONSE._serialized_start=494
  _SERVERMETADATARESPONSE._serialized_end=569
  _MODELMETADATAREQUEST._serialized_start=571
  _MODELMETADATAREQUEST._serialized_end=624
  _MODELMETADATARESPONSE._serialized_start=627
  _MODELMETADATARESPONSE._serialized_end=1002
  _MODELMETADATARESPONSE_TENSORMETADATA._serialized_start=939
  _MODELMETADATARESPONSE_TENSORMETADATA._serialized_end=1002
  _MODELINFERREQUEST._serialized_start=1005
  _MODELINFERREQUEST._serialized_end=2365
  _MODELINFERREQUEST_INFERINPUTTENSOR._serialized_start=1472
  _MODELINFERREQUEST_INFERINPUTTENSOR._serialized_end=1909
  _MODELINFERREQUEST_INFERINPUTTENSOR_PARAMETERSENTRY._serialized_start=1780
  _MODELINFERREQUEST_INFERINPUTTENSOR_PARAMETERSENTRY._serialized_end=1909
  _MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR._serialized_start=1912
  _MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR._serialized_end=2233
  _MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR_PARAMETERSENTRY._serialized_start=1780
  _MODELINFERREQUEST_INFERREQUESTEDOUTPUTTENSOR_PARAMETERSENTRY._serialized_end=1909
  _MODELINFERREQUEST_PARAMETERSENTRY._serialized_start=1780
  _MODELINFERREQUEST_PARAMETERSENTRY._serialized_end=1909
  _MODELINFERRESPONSE._serialized_start=2368
  _MODELINFERRESPONSE._serialized_end=3286
  _MODELINFERRESPONSE_INFEROUTPUTTENSOR._serialized_start=2714
  _MODELINFERRESPONSE_INFEROUTPUTTENSOR._serialized_end=3154
  _MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY._serialized_start=1780
  _MODELINFERRESPONSE_INFEROUTPUTTENSOR_PARAMETERSENTRY._serialized_end=1909
  _MODELINFERRESPONSE_PARAMETERSENTRY._serialized_start=1780
  _MODELINFERRESPONSE_PARAMETERSENTRY._serialized_end=1909
  _INFERPARAMETER._serialized_start=3288
  _INFERPARAMETER._serialized_end=3393
  _INFERTENSORCONTENTS._serialized_start=3396
  _INFERTENSORCONTENTS._serialized_end=3604
  _PREDICTORINFO._serialized_start=3607
  _PREDICTORINFO._serialized_end=3852
  _MODELINFO._serialized_start=3855
  _MODELINFO._serialized_end=4170
  _SCHEMAINFO._serialized_start=4172
  _SCHEMAINFO._serialized_end=4277
  _COLUMNINFO._serialized_start=4279
  _COLUMNINFO._serialized_end=4403
  _GETPREDICTORREQUEST._serialized_start=4405
  _GETPREDICTORREQUEST._serialized_end=4426
  _GETPREDICTORRESPONSE._serialized_start=4428
  _GETPREDICTORRESPONSE._serialized_end=4543
  _GETMODELREQUEST._serialized_start=4545
  _GETMODELREQUEST._serialized_end=4576
  _GETMODELRESPONSE._serialized_start=4578
  _GETMODELRESPONSE._serialized_end=4685
  _PREDICTREQUEST._serialized_start=4688
  _PREDICTREQUEST._serialized_end=4820
  _PREDICTRESPONSE._serialized_start=4823
  _PREDICTRESPONSE._serialized_end=5098
  _PREDICTRESPONSE_SCORESENTRY._serialized_start=5053
  _PREDICTRESPONSE_SCORESENTRY._serialized_end=5098
  _PREDICTRESULTLINEITEM._serialized_start=5101
  _PREDICTRESULTLINEITEM._serialized_end=5438
  _PROBABILITYVALUE._serialized_start=5440
  _PROBABILITYVALUE._serialized_end=5494
  _SHAPVALUE._serialized_start=5496
  _SHAPVALUE._serialized_end=5539
  _GRPCINFERENCESERVICE._serialized_start=5542
  _GRPCINFERENCESERVICE._serialized_end=7309
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.k8score.v1 import k8score_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2


class CoreK8sServiceStub(object):
    """///////////////////////////// Jobs

    The Core K8s service is used to list and get a kubernetes object
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListK8sSecrets = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListK8sSecrets',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListSecretsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListSecretResponse.FromString,
                )
        self.GetK8sSecret = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetK8sSecret',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetSecretRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetSecretResponse.FromString,
                )
        self.ListK8sServices = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListK8sServices',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListServicesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListServicesResponse.FromString,
                )
        self.GetK8sService = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetK8sService',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetServiceRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetServiceResponse.FromString,
                )
        self.ListK8sDeployments = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListK8sDeployments',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListDeploymentsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListDeploymentsResponse.FromString,
                )
        self.GetK8sDeployment = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetK8sDeployment',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetDeploymentRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetDeploymentResponse.FromString,
                )
        self.ListK8sPods = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListK8sPods',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListPodsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListPodsResponse.FromString,
                )
        self.GetK8sPod = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetK8sPod',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetPodRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetPodResponse.FromString,
                )
        self.ListK8sJobs = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListK8sJobs',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListJobsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListJobsResponse.FromString,
                )
        self.GetK8sJob = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetK8sJob',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetJobRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetJobResponse.FromString,
                )
        self.ListEvents = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListEvents',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListEventsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListEventsResponse.FromString,
                )
        self.GetContainerLog = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetContainerLog',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetContainerLogRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetContainerLogResponse.FromString,
                )


class CoreK8sServiceServicer(object):
    """///////////////////////////// Jobs

    The Core K8s service is used to list and get a kubernetes object
    """

    def ListK8sSecrets(self, request, context):
        """//////////////// secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetK8sSecret(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListK8sServices(self, request, context):
        """//////////////// service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetK8sService(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListK8sDeployments(self, request, context):
        """//////////////// deployment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetK8sDeployment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListK8sPods(self, request, context):
        """//////////////// pod
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetK8sPod(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListK8sJobs(self, request, context):
        """////////////// jobs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetK8sJob(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEvents(self, request, context):
        """Events

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContainerLog(self, request, context):
        """//////////////////////////// container log
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CoreK8sServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListK8sSecrets': grpc.unary_unary_rpc_method_handler(
                    servicer.ListK8sSecrets,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListSecretsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListSecretResponse.SerializeToString,
            ),
            'GetK8sSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetK8sSecret,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetSecretRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetSecretResponse.SerializeToString,
            ),
            'ListK8sServices': grpc.unary_unary_rpc_method_handler(
                    servicer.ListK8sServices,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListServicesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListServicesResponse.SerializeToString,
            ),
            'GetK8sService': grpc.unary_unary_rpc_method_handler(
                    servicer.GetK8sService,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetServiceRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetServiceResponse.SerializeToString,
            ),
            'ListK8sDeployments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListK8sDeployments,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListDeploymentsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListDeploymentsResponse.SerializeToString,
            ),
            'GetK8sDeployment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetK8sDeployment,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetDeploymentRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetDeploymentResponse.SerializeToString,
            ),
            'ListK8sPods': grpc.unary_unary_rpc_method_handler(
                    servicer.ListK8sPods,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListPodsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListPodsResponse.SerializeToString,
            ),
            'GetK8sPod': grpc.unary_unary_rpc_method_handler(
                    servicer.GetK8sPod,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetPodRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetPodResponse.SerializeToString,
            ),
            'ListK8sJobs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListK8sJobs,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListJobsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListJobsResponse.SerializeToString,
            ),
            'GetK8sJob': grpc.unary_unary_rpc_method_handler(
                    servicer.GetK8sJob,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetJobRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetJobResponse.SerializeToString,
            ),
            'ListEvents': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEvents,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListEventsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListEventsResponse.SerializeToString,
            ),
            'GetContainerLog': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContainerLog,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetContainerLogRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetContainerLogResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CoreK8sService(object):
    """///////////////////////////// Jobs

    The Core K8s service is used to list and get a kubernetes object
    """

    @staticmethod
    def ListK8sSecrets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListK8sSecrets',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListSecretsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetK8sSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetK8sSecret',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetSecretRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListK8sServices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListK8sServices',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListServicesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListServicesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetK8sService(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetK8sService',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetServiceRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetServiceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListK8sDeployments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListK8sDeployments',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListDeploymentsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListDeploymentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetK8sDeployment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetK8sDeployment',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetDeploymentRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetDeploymentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListK8sPods(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListK8sPods',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListPodsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListPodsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetK8sPod(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetK8sPod',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetPodRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetPodResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListK8sJobs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListK8sJobs',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListJobsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListJobsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetK8sJob(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetK8sJob',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetJobRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetJobResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEvents(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/ListEvents',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListEventsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.ListEventsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContainerLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.k8score.v1.CoreK8sService/GetContainerLog',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetContainerLogRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_k8score_dot_v1_dot_k8score__pb2.GetContainerLogResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/k8score/v1/k8score.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2
from k8s.io.api.apps.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_apps_dot_v1_dot_generated__pb2
from k8s.io.api.rbac.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_rbac_dot_v1_dot_generated__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/k8score/v1/k8score.proto\x12\x31github.com.metaprov.modelaapi.services.k8score.v1\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a\"k8s.io/api/core/v1/generated.proto\x1a\"k8s.io/api/apps/v1/generated.proto\x1a\"k8s.io/api/rbac/v1/generated.proto\x1a\x1cgoogle/api/annotations.proto\"\xc3\x01\n\x10GetSecretRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12_\n\x06labels\x18\x03 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x11GetSecretResponse\x12M\n\x06secret\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.services.k8score.v1.SecretInfo\"\xb9\x01\n\x12ListSecretsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x61\n\x06labels\x18\x03 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n\x12ListSecretResponse\x12N\n\x07secrets\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.services.k8score.v1.SecretInfo\"\xcb\x01\n\x14GetDeploymentRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x63\n\x06labels\x18\x03 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x15GetDeploymentResponse\x12U\n\ndeployment\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo\"\xc1\x01\n\x16ListDeploymentsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x65\n\x06labels\x18\x03 \x03(\x0b\x32U.github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x17ListDeploymentsResponse\x12V\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo\"\xc5\x01\n\x11GetServiceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12`\n\x06labels\x18\x03 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x12GetServiceResponse\x12O\n\x07service\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo\"\xbb\x01\n\x13ListServicesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x03 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x14ListServicesResponse\x12P\n\x08services\x18\x01 \x03(\x0b\x32>.github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo\"\xbd\x01\n\rGetPodRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\\\n\x06labels\x18\x03 \x03(\x0b\x32L.github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\x0eGetPodResponse\x12G\n\x03pod\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.services.k8score.v1.PodInfo\"\xb3\x01\n\x0fListPodsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12^\n\x06labels\x18\x02 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n\x10ListPodsResponse\x12H\n\x04pods\x18\x01 \x03(\x0b\x32:.github.com.metaprov.modelaapi.services.k8score.v1.PodInfo\"\xbd\x01\n\rGetJobRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\\\n\x06labels\x18\x03 \x03(\x0b\x32L.github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\x0eGetJobResponse\x12G\n\x03job\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.services.k8score.v1.JobInfo\"\xc3\x01\n\x0fListJobsRequest\x12\x0e\n\x06tenant\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12^\n\x06labels\x18\x03 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n\x10ListJobsResponse\x12H\n\x04jobs\x18\x01 \x03(\x0b\x32:.github.com.metaprov.modelaapi.services.k8score.v1.JobInfo\"P\n\x16GetContainerLogRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rcontainername\x18\x03 \x01(\t\"&\n\x17GetContainerLogResponse\x12\x0b\n\x03log\x18\x01 \x01(\x0c\"\xc5\x01\n\x11ListEventsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12`\n\x06labels\x18\x03 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"B\n\x12ListEventsResponse\x12,\n\x05items\x18\x01 \x01(\x0b\x32\x1d.k8s.io.api.core.v1.EventList\"-\n\nSecretInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"\xc5\x02\n\x0bServiceInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12Z\n\x06labels\x18\x03 \x03(\x0b\x32J.github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo.LabelsEntry\x12\n\n\x02ip\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\t\x12=\n\tcreatedAt\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x31\n\x06status\x18\x07 \x01(\x0b\x32!.k8s.io.api.core.v1.ServiceStatus\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"9\n\rContainerInfo\x12\r\n\x05image\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03log\x18\x03 \x01(\x0c\"\xfe\x02\n\x0e\x44\x65ploymentInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12]\n\x06labels\x18\x03 \x03(\x0b\x32M.github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo.LabelsEntry\x12=\n\tcreatedAt\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x34\n\x06status\x18\x05 \x01(\x0b\x32$.k8s.io.api.apps.v1.DeploymentStatus\x12H\n\x04pods\x18\x06 \x03(\x0b\x32:.github.com.metaprov.modelaapi.services.k8score.v1.PodInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf6\x02\n\x07PodInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12V\n\x06labels\x18\x03 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.services.k8score.v1.PodInfo.LabelsEntry\x12=\n\tcreatedAt\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12-\n\x06status\x18\x05 \x01(\x0b\x32\x1d.k8s.io.api.core.v1.PodStatus\x12U\n\x0b\x63ontrainers\x18\x06 \x03(\x0b\x32@.github.com.metaprov.modelaapi.services.k8score.v1.ContainerInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xec\x03\n\x07JobInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12V\n\x06labels\x18\x03 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.services.k8score.v1.JobInfo.LabelsEntry\x12=\n\tstartedAt\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12?\n\x0b\x63ompletedAt\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06\x66\x61iled\x18\x06 \x01(\x05\x12\x11\n\tsucceeded\x18\x07 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x08 \x01(\x05\x12\r\n\x05ready\x18\t \x01(\x05\x12H\n\x04pods\x18\n \x03(\x0b\x32:.github.com.metaprov.modelaapi.services.k8score.v1.PodInfo\x12\r\n\x05model\x18\x0b \x01(\t\x12\r\n\x05study\x18\x0c \x01(\t\x12\x0f\n\x07\x64\x61taset\x18\r \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\xaf\x12\n\x0e\x43oreK8sService\x12\xbf\x01\n\x0eListK8sSecrets\x12\x45.github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest\x1a\x45.github.com.metaprov.modelaapi.services.k8score.v1.ListSecretResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/secrets/{namespace}\x12\xc1\x01\n\x0cGetK8sSecret\x12\x43.github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest\x1a\x44.github.com.metaprov.modelaapi.services.k8score.v1.GetSecretResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/secrets/{namespace}/{name}\x12\xc4\x01\n\x0fListK8sServices\x12\x46.github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest\x1aG.github.com.metaprov.modelaapi.services.k8score.v1.ListServicesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/services/{namespace}\x12\xc5\x01\n\rGetK8sService\x12\x44.github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest\x1a\x45.github.com.metaprov.modelaapi.services.k8score.v1.GetServiceResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/services/{namespace}/{name}\x12\xd0\x01\n\x12ListK8sDeployments\x12I.github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest\x1aJ.github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/deployments/{namespace}\x12\xd1\x01\n\x10GetK8sDeployment\x12G.github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest\x1aH.github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/deployments/{namespace}/{name}\x12\xb4\x01\n\x0bListK8sPods\x12\x42.github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest\x1a\x43.github.com.metaprov.modelaapi.services.k8score.v1.ListPodsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/pods/{namespace}\x12\xb5\x01\n\tGetK8sPod\x12@.github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest\x1a\x41.github.com.metaprov.modelaapi.services.k8score.v1.GetPodResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/pods/{namespace}/{name}\x12\xb4\x01\n\x0bListK8sJobs\x12\x42.github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest\x1a\x43.github.com.metaprov.modelaapi.services.k8score.v1.ListJobsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/jobs/{namespace}\x12\xb5\x01\n\tGetK8sJob\x12@.github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest\x1a\x41.github.com.metaprov.modelaapi.services.k8score.v1.GetJobResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/jobs/{namespace}/{name}\x12\xb9\x01\n\nListEvents\x12\x44.github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest\x1a\x45.github.com.metaprov.modelaapi.services.k8score.v1.ListEventsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/events/{namespace}\x12\xc6\x01\n\x0fGetContainerLog\x12I.github.com.metaprov.modelaapi.services.k8score.v1.GetContainerLogRequest\x1aJ.github.com.metaprov.modelaapi.services.k8score.v1.GetContainerLogResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/pods/{namespace}B3Z1github.com/metaprov/modelaapi/services/k8score/v1b\x06proto3')



_GETSECRETREQUEST = DESCRIPTOR.message_types_by_name['GetSecretRequest']
_GETSECRETREQUEST_LABELSENTRY = _GETSECRETREQUEST.nested_types_by_name['LabelsEntry']
_GETSECRETRESPONSE = DESCRIPTOR.message_types_by_name['GetSecretResponse']
_LISTSECRETSREQUEST = DESCRIPTOR.message_types_by_name['ListSecretsRequest']
_LISTSECRETSREQUEST_LABELSENTRY = _LISTSECRETSREQUEST.nested_types_by_name['LabelsEntry']
_LISTSECRETRESPONSE = DESCRIPTOR.message_types_by_name['ListSecretResponse']
_GETDEPLOYMENTREQUEST = DESCRIPTOR.message_types_by_name['GetDeploymentRequest']
_GETDEPLOYMENTREQUEST_LABELSENTRY = _GETDEPLOYMENTREQUEST.nested_types_by_name['LabelsEntry']
_GETDEPLOYMENTRESPONSE = DESCRIPTOR.message_types_by_name['GetDeploymentResponse']
_LISTDEPLOYMENTSREQUEST = DESCRIPTOR.message_types_by_name['ListDeploymentsRequest']
_LISTDEPLOYMENTSREQUEST_LABELSENTRY = _LISTDEPLOYMENTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTDEPLOYMENTSRESPONSE = DESCRIPTOR.message_types_by_name['ListDeploymentsResponse']
_GETSERVICEREQUEST = DESCRIPTOR.message_types_by_name['GetServiceRequest']
_GETSERVICEREQUEST_LABELSENTRY = _GETSERVICEREQUEST.nested_types_by_name['LabelsEntry']
_GETSERVICERESPONSE = DESCRIPTOR.message_types_by_name['GetServiceResponse']
_LISTSERVICESREQUEST = DESCRIPTOR.message_types_by_name['ListServicesRequest']
_LISTSERVICESREQUEST_LABELSENTRY = _LISTSERVICESREQUEST.nested_types_by_name['LabelsEntry']
_LISTSERVICESRESPONSE = DESCRIPTOR.message_types_by_name['ListServicesResponse']
_GETPODREQUEST = DESCRIPTOR.message_types_by_name['GetPodRequest']
_GETPODREQUEST_LABELSENTRY = _GETPODREQUEST.nested_types_by_name['LabelsEntry']
_GETPODRESPONSE = DESCRIPTOR.message_types_by_name['GetPodResponse']
_LISTPODSREQUEST = DESCRIPTOR.message_types_by_name['ListPodsRequest']
_LISTPODSREQUEST_LABELSENTRY = _LISTPODSREQUEST.nested_types_by_name['LabelsEntry']
_LISTPODSRESPONSE = DESCRIPTOR.message_types_by_name['ListPodsResponse']
_GETJOBREQUEST = DESCRIPTOR.message_types_by_name['GetJobRequest']
_GETJOBREQUEST_LABELSENTRY = _GETJOBREQUEST.nested_types_by_name['LabelsEntry']
_GETJOBRESPONSE = DESCRIPTOR.message_types_by_name['GetJobResponse']
_LISTJOBSREQUEST = DESCRIPTOR.message_types_by_name['ListJobsRequest']
_LISTJOBSREQUEST_LABELSENTRY = _LISTJOBSREQUEST.nested_types_by_name['LabelsEntry']
_LISTJOBSRESPONSE = DESCRIPTOR.message_types_by_name['ListJobsResponse']
_GETCONTAINERLOGREQUEST = DESCRIPTOR.message_types_by_name['GetContainerLogRequest']
_GETCONTAINERLOGRESPONSE = DESCRIPTOR.message_types_by_name['GetContainerLogResponse']
_LISTEVENTSREQUEST = DESCRIPTOR.message_types_by_name['ListEventsRequest']
_LISTEVENTSREQUEST_LABELSENTRY = _LISTEVENTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTEVENTSRESPONSE = DESCRIPTOR.message_types_by_name['ListEventsResponse']
_SECRETINFO = DESCRIPTOR.message_types_by_name['SecretInfo']
_SERVICEINFO = DESCRIPTOR.message_types_by_name['ServiceInfo']
_SERVICEINFO_LABELSENTRY = _SERVICEINFO.nested_types_by_name['LabelsEntry']
_CONTAINERINFO = DESCRIPTOR.message_types_by_name['ContainerInfo']
_DEPLOYMENTINFO = DESCRIPTOR.message_types_by_name['DeploymentInfo']
_DEPLOYMENTINFO_LABELSENTRY = _DEPLOYMENTINFO.nested_types_by_name['LabelsEntry']
_PODINFO = DESCRIPTOR.message_types_by_name['PodInfo']
_PODINFO_LABELSENTRY = _PODINFO.nested_types_by_name['LabelsEntry']
_JOBINFO = DESCRIPTOR.message_types_by_name['JobInfo']
_JOBINFO_LABELSENTRY = _JOBINFO.nested_types_by_name['LabelsEntry']
GetSecretRequest = _reflection.GeneratedProtocolMessageType('GetSecretRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETSECRETREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETSECRETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetSecretRequest)
  })
_sym_db.RegisterMessage(GetSecretRequest)
_sym_db.RegisterMessage(GetSecretRequest.LabelsEntry)

GetSecretResponse = _reflection.GeneratedProtocolMessageType('GetSecretResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSECRETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetSecretResponse)
  })
_sym_db.RegisterMessage(GetSecretResponse)

ListSecretsRequest = _reflection.GeneratedProtocolMessageType('ListSecretsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSECRETSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSECRETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListSecretsRequest)
  })
_sym_db.RegisterMessage(ListSecretsRequest)
_sym_db.RegisterMessage(ListSecretsRequest.LabelsEntry)

ListSecretResponse = _reflection.GeneratedProtocolMessageType('ListSecretResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSECRETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListSecretResponse)
  })
_sym_db.RegisterMessage(ListSecretResponse)

GetDeploymentRequest = _reflection.GeneratedProtocolMessageType('GetDeploymentRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETDEPLOYMENTREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETDEPLOYMENTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentRequest)
  })
_sym_db.RegisterMessage(GetDeploymentRequest)
_sym_db.RegisterMessage(GetDeploymentRequest.LabelsEntry)

GetDeploymentResponse = _reflection.GeneratedProtocolMessageType('GetDeploymentResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDEPLOYMENTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetDeploymentResponse)
  })
_sym_db.RegisterMessage(GetDeploymentResponse)

ListDeploymentsRequest = _reflection.GeneratedProtocolMessageType('ListDeploymentsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDEPLOYMENTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDEPLOYMENTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsRequest)
  })
_sym_db.RegisterMessage(ListDeploymentsRequest)
_sym_db.RegisterMessage(ListDeploymentsRequest.LabelsEntry)

ListDeploymentsResponse = _reflection.GeneratedProtocolMessageType('ListDeploymentsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDEPLOYMENTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListDeploymentsResponse)
  })
_sym_db.RegisterMessage(ListDeploymentsResponse)

GetServiceRequest = _reflection.GeneratedProtocolMessageType('GetServiceRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETSERVICEREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETSERVICEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetServiceRequest)
  })
_sym_db.RegisterMessage(GetServiceRequest)
_sym_db.RegisterMessage(GetServiceRequest.LabelsEntry)

GetServiceResponse = _reflection.GeneratedProtocolMessageType('GetServiceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetServiceResponse)
  })
_sym_db.RegisterMessage(GetServiceResponse)

ListServicesRequest = _reflection.GeneratedProtocolMessageType('ListServicesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSERVICESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSERVICESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListServicesRequest)
  })
_sym_db.RegisterMessage(ListServicesRequest)
_sym_db.RegisterMessage(ListServicesRequest.LabelsEntry)

ListServicesResponse = _reflection.GeneratedProtocolMessageType('ListServicesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVICESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListServicesResponse)
  })
_sym_db.RegisterMessage(ListServicesResponse)

GetPodRequest = _reflection.GeneratedProtocolMessageType('GetPodRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETPODREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETPODREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetPodRequest)
  })
_sym_db.RegisterMessage(GetPodRequest)
_sym_db.RegisterMessage(GetPodRequest.LabelsEntry)

GetPodResponse = _reflection.GeneratedProtocolMessageType('GetPodResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPODRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetPodResponse)
  })
_sym_db.RegisterMessage(GetPodResponse)

ListPodsRequest = _reflection.GeneratedProtocolMessageType('ListPodsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPODSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPODSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListPodsRequest)
  })
_sym_db.RegisterMessage(ListPodsRequest)
_sym_db.RegisterMessage(ListPodsRequest.LabelsEntry)

ListPodsResponse = _reflection.GeneratedProtocolMessageType('ListPodsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPODSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListPodsResponse)
  })
_sym_db.RegisterMessage(ListPodsResponse)

GetJobRequest = _reflection.GeneratedProtocolMessageType('GetJobRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETJOBREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETJOBREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetJobRequest)
  })
_sym_db.RegisterMessage(GetJobRequest)
_sym_db.RegisterMessage(GetJobRequest.LabelsEntry)

GetJobResponse = _reflection.GeneratedProtocolMessageType('GetJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetJobResponse)
  })
_sym_db.RegisterMessage(GetJobResponse)

ListJobsRequest = _reflection.GeneratedProtocolMessageType('ListJobsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTJOBSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTJOBSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListJobsRequest)
  })
_sym_db.RegisterMessage(ListJobsRequest)
_sym_db.RegisterMessage(ListJobsRequest.LabelsEntry)

ListJobsResponse = _reflection.GeneratedProtocolMessageType('ListJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListJobsResponse)
  })
_sym_db.RegisterMessage(ListJobsResponse)

GetContainerLogRequest = _reflection.GeneratedProtocolMessageType('GetContainerLogRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTAINERLOGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetContainerLogRequest)
  })
_sym_db.RegisterMessage(GetContainerLogRequest)

GetContainerLogResponse = _reflection.GeneratedProtocolMessageType('GetContainerLogResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONTAINERLOGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.GetContainerLogResponse)
  })
_sym_db.RegisterMessage(GetContainerLogResponse)

ListEventsRequest = _reflection.GeneratedProtocolMessageType('ListEventsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTEVENTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTEVENTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListEventsRequest)
  })
_sym_db.RegisterMessage(ListEventsRequest)
_sym_db.RegisterMessage(ListEventsRequest.LabelsEntry)

ListEventsResponse = _reflection.GeneratedProtocolMessageType('ListEventsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ListEventsResponse)
  })
_sym_db.RegisterMessage(ListEventsResponse)

SecretInfo = _reflection.GeneratedProtocolMessageType('SecretInfo', (_message.Message,), {
  'DESCRIPTOR' : _SECRETINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.SecretInfo)
  })
_sym_db.RegisterMessage(SecretInfo)

ServiceInfo = _reflection.GeneratedProtocolMessageType('ServiceInfo', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SERVICEINFO_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _SERVICEINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ServiceInfo)
  })
_sym_db.RegisterMessage(ServiceInfo)
_sym_db.RegisterMessage(ServiceInfo.LabelsEntry)

ContainerInfo = _reflection.GeneratedProtocolMessageType('ContainerInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.ContainerInfo)
  })
_sym_db.RegisterMessage(ContainerInfo)

DeploymentInfo = _reflection.GeneratedProtocolMessageType('DeploymentInfo', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYMENTINFO_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _DEPLOYMENTINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.DeploymentInfo)
  })
_sym_db.RegisterMessage(DeploymentInfo)
_sym_db.RegisterMessage(DeploymentInfo.LabelsEntry)

PodInfo = _reflection.GeneratedProtocolMessageType('PodInfo', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODINFO_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.PodInfo.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _PODINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.PodInfo)
  })
_sym_db.RegisterMessage(PodInfo)
_sym_db.RegisterMessage(PodInfo.LabelsEntry)

JobInfo = _reflection.GeneratedProtocolMessageType('JobInfo', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _JOBINFO_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.JobInfo.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _JOBINFO,
  '__module__' : 'github.com.metaprov.modelaapi.services.k8score.v1.k8score_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.k8score.v1.JobInfo)
  })
_sym_db.RegisterMessage(JobInfo)
_sym_db.RegisterMessage(JobInfo.LabelsEntry)

_COREK8SSERVICE = DESCRIPTOR.services_by_name['CoreK8sService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/k8score/v1'
  _GETSECRETREQUEST_LABELSENTRY._options = None
  _GETSECRETREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTSECRETSREQUEST_LABELSENTRY._options = None
  _LISTSECRETSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _GETDEPLOYMENTREQUEST_LABELSENTRY._options = None
  _GETDEPLOYMENTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTDEPLOYMENTSREQUEST_LABELSENTRY._options = None
  _LISTDEPLOYMENTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _GETSERVICEREQUEST_LABELSENTRY._options = None
  _GETSERVICEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTSERVICESREQUEST_LABELSENTRY._options = None
  _LISTSERVICESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _GETPODREQUEST_LABELSENTRY._options = None
  _GETPODREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTPODSREQUEST_LABELSENTRY._options = None
  _LISTPODSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _GETJOBREQUEST_LABELSENTRY._options = None
  _GETJOBREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTJOBSREQUEST_LABELSENTRY._options = None
  _LISTJOBSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTEVENTSREQUEST_LABELSENTRY._options = None
  _LISTEVENTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _SERVICEINFO_LABELSENTRY._options = None
  _SERVICEINFO_LABELSENTRY._serialized_options = b'8\001'
  _DEPLOYMENTINFO_LABELSENTRY._options = None
  _DEPLOYMENTINFO_LABELSENTRY._serialized_options = b'8\001'
  _PODINFO_LABELSENTRY._options = None
  _PODINFO_LABELSENTRY._serialized_options = b'8\001'
  _JOBINFO_LABELSENTRY._options = None
  _JOBINFO_LABELSENTRY._serialized_options = b'8\001'
  _COREK8SSERVICE.methods_by_name['ListK8sSecrets']._options = None
  _COREK8SSERVICE.methods_by_name['ListK8sSecrets']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/secrets/{namespace}'
  _COREK8SSERVICE.methods_by_name['GetK8sSecret']._options = None
  _COREK8SSERVICE.methods_by_name['GetK8sSecret']._serialized_options = b'\202\323\344\223\002 \022\036/v1/secrets/{namespace}/{name}'
  _COREK8SSERVICE.methods_by_name['ListK8sServices']._options = None
  _COREK8SSERVICE.methods_by_name['ListK8sServices']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/services/{namespace}'
  _COREK8SSERVICE.methods_by_name['GetK8sService']._options = None
  _COREK8SSERVICE.methods_by_name['GetK8sService']._serialized_options = b'\202\323\344\223\002!\022\037/v1/services/{namespace}/{name}'
  _COREK8SSERVICE.methods_by_name['ListK8sDeployments']._options = None
  _COREK8SSERVICE.methods_by_name['ListK8sDeployments']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/deployments/{namespace}'
  _COREK8SSERVICE.methods_by_name['GetK8sDeployment']._options = None
  _COREK8SSERVICE.methods_by_name['GetK8sDeployment']._serialized_options = b'\202\323\344\223\002$\022\"/v1/deployments/{namespace}/{name}'
  _COREK8SSERVICE.methods_by_name['ListK8sPods']._options = None
  _COREK8SSERVICE.methods_by_name['ListK8sPods']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/pods/{namespace}'
  _COREK8SSERVICE.methods_by_name['GetK8sPod']._options = None
  _COREK8SSERVICE.methods_by_name['GetK8sPod']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/pods/{namespace}/{name}'
  _COREK8SSERVICE.methods_by_name['ListK8sJobs']._options = None
  _COREK8SSERVICE.methods_by_name['ListK8sJobs']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/jobs/{namespace}'
  _COREK8SSERVICE.methods_by_name['GetK8sJob']._options = None
  _COREK8SSERVICE.methods_by_name['GetK8sJob']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/jobs/{namespace}/{name}'
  _COREK8SSERVICE.methods_by_name['ListEvents']._options = None
  _COREK8SSERVICE.methods_by_name['ListEvents']._serialized_options = b'\202\323\344\223\002\030\022\026/v1/events/{namespace}'
  _COREK8SSERVICE.methods_by_name['GetContainerLog']._options = None
  _COREK8SSERVICE.methods_by_name['GetContainerLog']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/pods/{namespace}'
  _GETSECRETREQUEST._serialized_start=311
  _GETSECRETREQUEST._serialized_end=506
  _GETSECRETREQUEST_LABELSENTRY._serialized_start=461
  _GETSECRETREQUEST_LABELSENTRY._serialized_end=506
  _GETSECRETRESPONSE._serialized_start=508
  _GETSECRETRESPONSE._serialized_end=606
  _LISTSECRETSREQUEST._serialized_start=609
  _LISTSECRETSREQUEST._serialized_end=794
  _LISTSECRETSREQUEST_LABELSENTRY._serialized_start=461
  _LISTSECRETSREQUEST_LABELSENTRY._serialized_end=506
  _LISTSECRETRESPONSE._serialized_start=796
  _LISTSECRETRESPONSE._serialized_end=896
  _GETDEPLOYMENTREQUEST._serialized_start=899
  _GETDEPLOYMENTREQUEST._serialized_end=1102
  _GETDEPLOYMENTREQUEST_LABELSENTRY._serialized_start=461
  _GETDEPLOYMENTREQUEST_LABELSENTRY._serialized_end=506
  _GETDEPLOYMENTRESPONSE._serialized_start=1104
  _GETDEPLOYMENTRESPONSE._serialized_end=1214
  _LISTDEPLOYMENTSREQUEST._serialized_start=1217
  _LISTDEPLOYMENTSREQUEST._serialized_end=1410
  _LISTDEPLOYMENTSREQUEST_LABELSENTRY._serialized_start=461
  _LISTDEPLOYMENTSREQUEST_LABELSENTRY._serialized_end=506
  _LISTDEPLOYMENTSRESPONSE._serialized_start=1412
  _LISTDEPLOYMENTSRESPONSE._serialized_end=1525
  _GETSERVICEREQUEST._serialized_start=1528
  _GETSERVICEREQUEST._serialized_end=1725
  _GETSERVICEREQUEST_LABELSENTRY._serialized_start=461
  _GETSERVICEREQUEST_LABELSENTRY._serialized_end=506
  _GETSERVICERESPONSE._serialized_start=1727
  _GETSERVICERESPONSE._serialized_end=1828
  _LISTSERVICESREQUEST._serialized_start=1831
  _LISTSERVICESREQUEST._serialized_end=2018
  _LISTSERVICESREQUEST_LABELSENTRY._serialized_start=461
  _LISTSERVICESREQUEST_LABELSENTRY._serialized_end=506
  _LISTSERVICESRESPONSE._serialized_start=2020
  _LISTSERVICESRESPONSE._serialized_end=2124
  _GETPODREQUEST._serialized_start=2127
  _GETPODREQUEST._serialized_end=2316
  _GETPODREQUEST_LABELSENTRY._serialized_start=461
  _GETPODREQUEST_LABELSENTRY._serialized_end=506
  _GETPODRESPONSE._serialized_start=2318
  _GETPODRESPONSE._serialized_end=2407
  _LISTPODSREQUEST._serialized_start=2410
  _LISTPODSREQUEST._serialized_end=2589
  _LISTPODSREQUEST_LABELSENTRY._serialized_start=461
  _LISTPODSREQUEST_LABELSENTRY._serialized_end=506
  _LISTPODSRESPONSE._serialized_start=2591
  _LISTPODSRESPONSE._serialized_end=2683
  _GETJOBREQUEST._serialized_start=2686
  _GETJOBREQUEST._serialized_end=2875
  _GETJOBREQUEST_LABELSENTRY._serialized_start=461
  _GETJOBREQUEST_LABELSENTRY._serialized_end=506
  _GETJOBRESPONSE._serialized_start=2877
  _GETJOBRESPONSE._serialized_end=2966
  _LISTJOBSREQUEST._serialized_start=2969
  _LISTJOBSREQUEST._serialized_end=3164
  _LISTJOBSREQUEST_LABELSENTRY._serialized_start=461
  _LISTJOBSREQUEST_LABELSENTRY._serialized_end=506
  _LISTJOBSRESPONSE._serialized_start=3166
  _LISTJOBSRESPONSE._serialized_end=3258
  _GETCONTAINERLOGREQUEST._serialized_start=3260
  _GETCONTAINERLOGREQUEST._serialized_end=3340
  _GETCONTAINERLOGRESPONSE._serialized_start=3342
  _GETCONTAINERLOGRESPONSE._serialized_end=3380
  _LISTEVENTSREQUEST._serialized_start=3383
  _LISTEVENTSREQUEST._serialized_end=3580
  _LISTEVENTSREQUEST_LABELSENTRY._serialized_start=461
  _LISTEVENTSREQUEST_LABELSENTRY._serialized_end=506
  _LISTEVENTSRESPONSE._serialized_start=3582
  _LISTEVENTSRESPONSE._serialized_end=3648
  _SECRETINFO._serialized_start=3650
  _SECRETINFO._serialized_end=3695
  _SERVICEINFO._serialized_start=3698
  _SERVICEINFO._serialized_end=4023
  _SERVICEINFO_LABELSENTRY._serialized_start=461
  _SERVICEINFO_LABELSENTRY._serialized_end=506
  _CONTAINERINFO._serialized_start=4025
  _CONTAINERINFO._serialized_end=4082
  _DEPLOYMENTINFO._serialized_start=4085
  _DEPLOYMENTINFO._serialized_end=4467
  _DEPLOYMENTINFO_LABELSENTRY._serialized_start=461
  _DEPLOYMENTINFO_LABELSENTRY._serialized_end=506
  _PODINFO._serialized_start=4470
  _PODINFO._serialized_end=4844
  _PODINFO_LABELSENTRY._serialized_start=461
  _PODINFO_LABELSENTRY._serialized_end=506
  _JOBINFO._serialized_start=4847
  _JOBINFO._serialized_end=5339
  _JOBINFO_LABELSENTRY._serialized_start=461
  _JOBINFO_LABELSENTRY._serialized_end=506
  _COREK8SSERVICE._serialized_start=5342
  _COREK8SSERVICE._serialized_end=7693
# @@protoc_insertion_point(module_scope)
